@@ -21,7 +21,21 @@ async def hello(ctx: Context):
 
 """
 
-dockerfile_tpl = """ """
+dockerfile_tpl = """FROM python:slim-bullseye
+
+WORKDIR /app
+
+COPY requirements.txt /app/requirements.txt
+
+RUN pip install --no-cache-dir --upgrade -r /app/requirements.txt
+
+COPY src /app/src/
+COPY static /app/static/
+COPY templates /app/templates
+COPY app.yaml /app/app.yaml
+
+CMD ["uvicorn", "src.__solace__:app", "--host", "0.0.0.0", "--port", "5000"]
+"""
 
 default_config = {
     "env_name": "solace_dev",
@@ -32,6 +46,8 @@ default_config = {
     "templates_dir": "templates",
     "http_exception_type": "text",
     "context_tracers_enabled": False,
+    "enable_dynamic_routes": False,
+    "dynamic_routes_secret": None,
     "routes": [
         {
             "path": "/",
@@ -90,6 +106,7 @@ def init(
         write_config()
         write_dockerfile()
         write_src()
+        write_app()
         write_req()
 
     except FileExistsError:
@@ -115,7 +132,7 @@ def dev(
         port=port, 
         log_level=log_level,
         reload=reload,
-        reload_includes=["*.py", "*.toml", "*.json", "*.yaml", "*.env", ".env", "*.html", "*.js", "*.css"],
+        reload_includes=["*.py", "*.toml", "*.json", "*.yaml", "*.yml", "*.env", ".env", "*.html", "*.js", "*.css"],
         debug=debug,
         factory = False
     )
