@@ -13,9 +13,18 @@ class SolaceValidator:
     @property
     def errors(self):
         return self.validator.errors
+    
+    @property
+    def data(self):
+        return self.validator.validated(self.payload, self.schema)
+    
+    def get(self, property: str, default: Any = None):
+        if property in self.data:
+            return self.data.get(property)
+        return default
 
-    def __call__(self, data: dict):
+    def __call__(self, payload: dict):
+        self.payload = payload
         self.validator.allow_unknown = self.allow_unknown
         self.validator.require_all = self.require_all
-        self.props = self.validator.validated(data, self.schema)
-        return self.validator.validate(data, self.schema)
+        return self.validator.validate(payload, self.schema)
